==> revss_1.0.6.tar.gz: revss/README.md <==
---
title: Package revss
---
<!-- badges: start -->
[![](https://www.r-pkg.org/badges/version-last-release/revss)](https://cran.r-project.org/package=revss)
[![](http://cranlogs.r-pkg.org/badges/last-month/revss)](https://cran.r-project.org/package=revss)
[![](https://cranlogs.r-pkg.org/badges/grand-total/revss)](https://cran.r-project.org/package=revss)
[![R-CMD-check](https://github.com/aadler/revss/actions/workflows/R-CMD-check.yaml/badge.svg)](https://github.com/aadler/revss/actions/workflows/R-CMD-check.yaml)
[![Codecov test coverage](https://codecov.io/gh/aadler/revss/branch/master/graph/badge.svg)](https://app.codecov.io/gh/aadler/revss?branch=master)
[![OpenSSF Best Practices](https://bestpractices.coreinfrastructure.org/projects/5541/badge)](https://bestpractices.coreinfrastructure.org/projects/5541)
[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.5874911.svg)](https://doi.org/10.5281/zenodo.5874911)
<!-- badges: end -->

## Description
**revss** is an `R` package which implements the estimation techniques described
in [Rousseeuw & Verboven (2002)](https://www.researchgate.net/publication/223864903_Robust_estimation_in_very_small_samples)
for the location and scale of very small samples.

## Citation
If you use the package, please cite it as per
[CITATION](https://CRAN.R-project.org/package=minimaxApprox/citation.html).

## Acknowledgements
The author is grateful Dr. Peter Rousseeuw for his response to this
[MathExchange](https://math.stackexchange.com/q/2447019) question about the
implementation.

## Roadmap
### Major

 * There are no plans for major changes at current
 
### Minor
 
 * There are no plans for minor changes at current
 
## Contributions
Please see
[CONTRIBUTING.md](https://github.com/aadler/revss/blob/master/CONTRIBUTING.md).

## Security
Please see
[SECURITY.md](https://github.com/aadler/revss/blob/master/SECURITY.md).

==> revss_2.0.0.tar.gz: revss/README.md <==
---
title: Package revss
---
<!-- badges: start -->
[![](https://www.r-pkg.org/badges/version-last-release/revss)](https://cran.r-project.org/package=revss)
[![](http://cranlogs.r-pkg.org/badges/last-month/revss)](https://cran.r-project.org/package=revss)
[![](https://cranlogs.r-pkg.org/badges/grand-total/revss)](https://cran.r-project.org/package=revss)
[![R-CMD-check](https://github.com/aadler/revss/actions/workflows/R-CMD-check.yaml/badge.svg)](https://github.com/aadler/revss/actions/workflows/R-CMD-check.yaml)
[![codecov](https://codecov.io/gh/aadler/revss/graph/badge.svg?token=HbVHa1SFjv)](https://app.codecov.io/gh/aadler/revss)
[![OpenSSF Best Practices](https://bestpractices.coreinfrastructure.org/projects/5541/badge)](https://bestpractices.coreinfrastructure.org/projects/5541)
<!-- badges: end -->

## Description
**revss** is an `R` package which implements the estimation techniques described
in [Rousseeuw & Verboven (2002)](https://www.researchgate.net/publication/223864903_Robust_estimation_in_very_small_samples#fullTextFileContent)
for the location and scale of very small samples.

## Citation
If you use the package, please cite it as per
[CITATION](https://CRAN.R-project.org/package=minimaxApprox/citation.html).

## Acknowledgment
The author is grateful Dr. Peter Rousseeuw for his response to this
[MathExchange](https://math.stackexchange.com/q/2447019) question about the
implementation.

## Roadmap
### Major

 * There are no plans for major changes at current
 
### Minor
 
 * There are no plans for minor changes at current
 
## Contributions
Please see
[CONTRIBUTING.md](https://github.com/aadler/revss/blob/master/CONTRIBUTING.md).

## Security
Please see
[SECURITY.md](https://github.com/aadler/revss/blob/master/SECURITY.md).
